@@ -32,7 +32,7 @@ def iter_files(identifier, timeout=None):
 
 # modify_metadata()
 #_________________________________________________________________________________________
-def modify_metadata(identifier, metadata, target='metadata'):
+def modify_metadata(identifier, metadata, timeout=None, target='metadata'):
     item = get_item(identifier, metadata_timeout=timeout)
     return item.modify_metadata(metadata, target)
 
